// ===========================================================================
// CONTENT  : TEST CLASS SignatureAlgorithmTest
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 27/09/2014
// HISTORY  :
//  27/09/2014  mdu  CREATED
//
// Copyright (c) 2014, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.security;

// ===========================================================================
// IMPORTS
// ===========================================================================
import static org.junit.Assert.*;

import java.security.NoSuchAlgorithmException;
import java.security.Signature;

import org.junit.Test;
import org.pfsw.util.SysUtil;

public class SignatureAlgorithmTest
{
  // =========================================================================
  // TEST METHODS
  // =========================================================================
  @Test
  public void test_findByName()
  {
    SignatureAlgorithm algorithm;

    algorithm = SignatureAlgorithm.findByName("SHA512withRSA");
    assertNotNull(algorithm);
    assertEquals("RS512", algorithm.getJWAName());
  }

  @Test
  public void test_findByName_unknown()
  {
    SignatureAlgorithm algorithm;

    algorithm = SignatureAlgorithm.findByName("SHA1024withRSA");
    assertNull(algorithm);
  }

  @Test
  public void test_findByJWAName()
  {
    SignatureAlgorithm algorithm;

    algorithm = SignatureAlgorithm.findByJWAName("ES256");
    assertNotNull(algorithm);
    assertEquals("SHA256withECDSA", algorithm.getName());
  }

  @Test
  public void test_findByJWAName_unknown()
  {
    SignatureAlgorithm algorithm;

    algorithm = SignatureAlgorithm.findByJWAName("FS256");
    assertNull(algorithm);
  }

  @Test
  public void test_asSignature() throws NoSuchAlgorithmException
  {
    Signature signature;

    signature = SignatureAlgorithm.SHA256_WITH_RSA.asSignature();
    assertNotNull(signature);
  }

  @Test
  public void test_asSignature_exception()
  {
    if (SysUtil.current().getJavaRuntimeVersion() < 7)
    {      
      try
      {
        SignatureAlgorithm.SHA512_WITH_ECDSA.asSignature();
        fail("Expected NoSuchAlgorithmException");
      }
      catch (Exception ex)
      {
        assertTrue(ex instanceof NoSuchAlgorithmException);
      }
    }
    else
    {
      try
      {
        assertEquals("SHA512withECDSA", SignatureAlgorithm.SHA512_WITH_ECDSA.asSignature().getAlgorithm());
      }
      catch (NoSuchAlgorithmException e)
      {
        fail(e.toString());
      }
    }
  }
}
