package org.pfsw.security.authentication;

import static org.junit.Assert.*;

import org.junit.Test;
import org.pfsw.text.StringPattern;

public class LocationCredentialsTest
{
  private static final String REALM_1 = "unittest1";
  private static final String REALM_2 = "unittest2";
  
  @Test
  public void test_appliesTo()
  {
    LocationCredentials credentials = new LocationCredentials(REALM_1, "fflint", "Secret99");
    credentials.addPattern("https://server.company.com/app13/reserved/*");
    
    assertTrue(credentials.appliesTo(REALM_1, "https://server.company.com/app13/reserved/index.html"));
    assertTrue(credentials.appliesTo(REALM_1, "https://server.company.com/app13/reserved/invoice/123"));
    assertFalse(credentials.appliesTo(REALM_2, "https://server.company.com/app13/reserved/invoice/123"));
    assertFalse(credentials.appliesTo(null, "https://server.company.com/app13/reserved/invoice/123"));
    assertFalse(credentials.appliesTo(REALM_1, null));
    assertFalse(credentials.appliesTo(REALM_1, "https://server.company.com/app13/public/invoice/123"));
  }

  @Test
  public void test_appliesToURL()
  {
    LocationCredentials credentials = new LocationCredentials(REALM_1, "fflint", "Secret99");
    credentials.addPattern("https://server.company.com/app13/reserved/*");
    credentials.addPattern((String)null);
    credentials.addPattern((StringPattern)null);
    
    assertTrue(credentials.appliesToURL("https://server.company.com/app13/reserved/index.html"));
    assertFalse(credentials.appliesToURL("https://server.company.com/app131/reserved/index.html"));
    assertFalse(credentials.appliesToURL(null));
  }

  @Test
  public void test_appliesToRealm()
  {
    LocationCredentials credentials = new LocationCredentials(REALM_1, "fflint", "Secret99");
    credentials.addPattern("https://server.company.com/app13/reserved/*");
    
    assertTrue(credentials.appliesToRealm(REALM_1));
    assertFalse(credentials.appliesToRealm(REALM_2));
    assertFalse(credentials.appliesToRealm(null));
  }
}