// ===========================================================================
// CONTENT  : TEST CLASS HashMechanismTest
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 24/11/2013
// HISTORY  :
//  24/11/2013  mdu  CREATED
//
// Copyright (c) 2013, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.security.crypto;

// ===========================================================================
// IMPORTS
// ===========================================================================
import static org.junit.Assert.*;

import org.junit.Test;

/**
 * Test class for corresponding business class.
 *
 * @author Manfred Duchrow
 */
public class HashMechanismTest
{
  @Test
  public void test_getPrefix_unsalted()
  {
    assertEquals("{MD5}", HashMechanism.MD5.getPrefix());
    assertEquals("{SHA}", HashMechanism.SHA_1.getPrefix());
    assertEquals("{SHA256}", HashMechanism.SHA_2_256.getPrefix());
    assertEquals("{SHA384}", HashMechanism.SHA_2_384.getPrefix());
    assertEquals("{SHA512}", HashMechanism.SHA_2_512.getPrefix());
  }

  @Test
  public void test_getPrefix_salted()
  {
    assertEquals("{SMD5}", HashMechanism.SALTED_MD5.getPrefix());
    assertEquals("{SSHA}", HashMechanism.SALTED_SHA_1.getPrefix());
    assertEquals("{SSHA256}", HashMechanism.SALTED_SHA_2_256.getPrefix());
    assertEquals("{SSHA384}", HashMechanism.SALTED_SHA_2_384.getPrefix());
    assertEquals("{SSHA512}", HashMechanism.SALTED_SHA_2_512.getPrefix());
  }

  @Test
  public void test_getBitLength_unsalted()
  {
    assertEquals(128, HashMechanism.MD5.getBitLength());
    assertEquals(160, HashMechanism.SHA_1.getBitLength());
    assertEquals(256, HashMechanism.SHA_2_256.getBitLength());
    assertEquals(384, HashMechanism.SHA_2_384.getBitLength());
    assertEquals(512, HashMechanism.SHA_2_512.getBitLength());
  }

  @Test
  public void test_getBitLength_salted()
  {
    assertEquals(128, HashMechanism.SALTED_MD5.getBitLength());
    assertEquals(160, HashMechanism.SALTED_SHA_1.getBitLength());
    assertEquals(256, HashMechanism.SALTED_SHA_2_256.getBitLength());
    assertEquals(384, HashMechanism.SALTED_SHA_2_384.getBitLength());
    assertEquals(512, HashMechanism.SALTED_SHA_2_512.getBitLength());
  }

  @Test
  public void test_findHashMechanism_success()
  {
    assertNotNull(HashMechanism.findHashMechanism("MD5"));
    assertNotNull(HashMechanism.findHashMechanism("{MD5}"));
    assertNotNull(HashMechanism.findHashMechanism("SHA-1"));
    assertNotNull(HashMechanism.findHashMechanism("{sha}"));
    assertNotNull(HashMechanism.findHashMechanism("SSHA"));
    assertNotNull(HashMechanism.findHashMechanism("{SSHA}"));
    assertNotNull(HashMechanism.findHashMechanism("SHA256"));
    assertNotNull(HashMechanism.findHashMechanism("{sha256}"));
    assertNotNull(HashMechanism.findHashMechanism("SSHA256"));
    assertNotNull(HashMechanism.findHashMechanism("{SSHA256}"));
    assertNotNull(HashMechanism.findHashMechanism("SSHA384"));
    assertNotNull(HashMechanism.findHashMechanism("{SSHA384}"));
    assertNotNull(HashMechanism.findHashMechanism("SHA512"));
    assertNotNull(HashMechanism.findHashMechanism("{SHA512}"));
    assertNotNull(HashMechanism.findHashMechanism("ssha512"));
    assertNotNull(HashMechanism.findHashMechanism("{SSHA512}"));
  }

  @Test
  public void test_findHashMechanism_unknown()
  {
    assertNull(HashMechanism.findHashMechanism("UNKNOWN"));
  }

  @Test
  public void test_findHashMechanism_null()
  {
    assertNull(HashMechanism.findHashMechanism(null));
  }

  @Test
  public void test_toString()
  {
    assertEquals("HashMechanism(SSHA384)", HashMechanism.SALTED_SHA_2_384.toString());
  }

  @Test
  public void test_equals_and_hashCode_true()
  {
    HashMechanism hm;

    hm = HashMechanism.create(CheckedHashAlgorithm.MD5);
    assertTrue(hm.equals(HashMechanism.MD5));
    assertTrue(hm.hashCode() == HashMechanism.MD5.hashCode());

    hm = HashMechanism.create(CheckedHashAlgorithm.SHA_1);
    assertTrue(hm.equals(HashMechanism.SHA_1));
    assertTrue(hm.hashCode() == HashMechanism.SHA_1.hashCode());

    hm = HashMechanism.create(CheckedHashAlgorithm.SHA_2_256, true);
    assertTrue(hm.equals(HashMechanism.SALTED_SHA_2_256));
    assertTrue(hm.hashCode() == HashMechanism.SALTED_SHA_2_256.hashCode());

    hm = HashMechanism.create(CheckedHashAlgorithm.SHA_2_512);
    assertTrue(hm.equals(HashMechanism.SHA_2_512));
    assertTrue(hm.hashCode() == HashMechanism.SHA_2_512.hashCode());
  }

  @Test
  public void test_equals_and_hashCode_false()
  {
    HashMechanism hm;

    hm = HashMechanism.create(CheckedHashAlgorithm.MD5);
    assertFalse(hm.equals(HashMechanism.SHA_2_384));
    assertFalse(hm.equals(HashMechanism.SALTED_MD5));
    assertFalse(hm.hashCode() == HashMechanism.SALTED_MD5.hashCode());

    hm = HashMechanism.create(CheckedHashAlgorithm.SHA_1);
    assertFalse(hm.equals(HashMechanism.SHA_2_512));
    assertFalse(hm.hashCode() == HashMechanism.SALTED_SHA_1.hashCode());

    hm = HashMechanism.create(CheckedHashAlgorithm.SHA_2_256, true);
    assertFalse(hm.equals(HashMechanism.SALTED_SHA_2_384));
    assertFalse(hm.hashCode() == HashMechanism.SHA_2_256.hashCode());

    hm = HashMechanism.create(CheckedHashAlgorithm.SHA_2_512);
    assertFalse(hm.equals(HashMechanism.SALTED_SHA_2_256));
    assertFalse(hm.hashCode() == HashMechanism.SHA_2_384.hashCode());
    assertFalse(hm.equals("SHA-512"));
  }
}
