package org.pfsw.security.oauth.pkce;

import static org.junit.Assert.*;
import static org.pfsw.security.testhelper.UnitTestHelper.*;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;
import org.pfsw.security.testhelper.AlwaysNewPlainPKCEGenerator;
import org.pfsw.security.testhelper.PrimitiveRandomStringGenerator;

public class PlainPKCEGeneratorTest
{
  @Test
  public void test_generate()
  {
    assertPlainKey(PlainPKCEGenerator.instance().generate());
  }

  @Test
  public void test_newProofKey()
  {
    assertPlainKey(PlainPKCEGenerator.newProofKey());
  }
  
  @Test
  public void test_generate__different_keys_with_always_new_generator()
  {
    assertDifferentKeys(new AlwaysNewPlainPKCEGenerator());
  }
 
  @Test
  public void test_generate__different_keys_default_string_generator()
  {
    PlainPKCEGenerator pkceGenerator = PlainPKCEGenerator.create();
    assertDifferentKeys(pkceGenerator);
  }
  
  @Test
  public void test_generate__different_keys_other_string_generator()
  {
    PlainPKCEGenerator pkceGenerator = PlainPKCEGenerator.create(new PrimitiveRandomStringGenerator());
    assertDifferentKeys(pkceGenerator);
  }
  
  // ============== helper methods ======================================

  private void assertDifferentKeys(PKCEGenerator pkceGenerator) 
  {
    int numberOfTests = 5000;
    List<ProofKeyForCodeExchange> proofKeys = new ArrayList<ProofKeyForCodeExchange>();
    ProofKeyForCodeExchange proofKey;
    
    for (int i = 0; i < numberOfTests; i++)
    {
      proofKey = pkceGenerator.generate();
      assertPlainKey(proofKey);
      for (ProofKeyForCodeExchange previousKey : proofKeys)
      {
        assertFalse(proofKey.getCodeVerifier().equals(previousKey.getCodeVerifier()));
      }
      proofKeys.add(proofKey);
    }    
  }
}