// ===========================================================================
// CONTENT  : CLASS UnitTestHelper
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 27/09/2014
// HISTORY  :
//  27/09/2014  mdu  CREATED
//
// Copyright (c) 2014, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.security.testhelper;

import static org.junit.Assert.*;
import static org.pfsw.text.StringUtil.*;

import java.io.File;

import org.pfsw.security.oauth.pkce.CodeChallengeMethod;
import org.pfsw.security.oauth.pkce.ProofKeyForCodeExchange;

/**
 * @author Manfred Duchrow
 */
public class UnitTestHelper
{
  public static final String BASE_TESTDATA_DIR = System.getProperty("testdata.dir", "./src/test/testdata/");
  public static final String TESTDATA_DIR = BASE_TESTDATA_DIR + "pf-security";
  public static final String TESTDATA = TESTDATA_DIR + "/";

  public static final String CERT_FINGERPRINT_004 = "7C:F9:25:D7:CC:3C:82:BA:13:68:3A:9D:A0:2F:CD:49:1D:D3:C7:89";
  public static final String CERT_FINGERPRINT_008 = "BE818B70FD7F81865EB2F9ED69A0D4E54841DDBB";

  private static final String PKCE_ALLOWED_CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-._~";

  public static File testDataFile(String filePath)
  {
    return new File(TESTDATA + filePath);
  }

  public static void assertProofKeyCodeVerifier(String codeVerifier)
  {
    assertTrue("Code verifier string is too short", codeVerifier.length() >= 43);
    assertTrue("Code verifier string is too long", codeVerifier.length() <= 128);
    for (char ch : codeVerifier.toCharArray())
    {
      assertTrue(String.format("Character '%s' not allowed in code verifier string", ch), SU.contains(PKCE_ALLOWED_CHARS, ch));
    }
  }

  public static void assertPlainKey(ProofKeyForCodeExchange proofKey)
  {
    assertEquals(proofKey.getCodeVerifier(), proofKey.getCodeChallenge());
    assertTrue(CodeChallengeMethod.PLAIN == proofKey.getCodeChallengeMethod());
    assertProofKeyCodeVerifier(proofKey.getCodeVerifier());
  }
}
